@@ -142,6 +142,36 @@ def configure_parser(parser, version):
         "--end", default=None, type=int, help="end at the given line"
     )
 
+    # "queue"
+    if version >= (2019, 1):
+        jobs_queue = sub.add_parser("queue", help="job queue")
+        jobs_queue.add_argument(
+            "device_types", nargs="*", help="filter by device-types"
+        )
+        out_format = jobs_queue.add_mutually_exclusive_group()
+        out_format.add_argument(
+            "--json",
+            dest="output_format",
+            default=None,
+            action="store_const",
+            const="json",
+            help="print as json",
+        )
+        out_format.add_argument(
+            "--yaml",
+            dest="output_format",
+            action="store_const",
+            const="yaml",
+            default=None,
+            help="print as yaml",
+        )
+        jobs_queue.add_argument(
+            "--start", type=int, default=0, help="skip the N first jobs [default=0]"
+        )
+        jobs_queue.add_argument(
+            "--limit", type=int, default=25, help="limit to N jobs [default=25]"
+        )
+
     # "resubmit"
     jobs_resubmit = sub.add_parser("resubmit", help="resubmit a job")
     jobs_resubmit.add_argument("job_id", help="job id")
@@ -511,6 +541,30 @@ def handle_logs(proxy, options, config):
     return 0
 
 
+def handle_queue(proxy, options, config):
+    dts = options.device_types if options.device_types else None
+    data = proxy.scheduler.jobs.queue(dts, options.start, options.limit)
+    if options.output_format == "json":
+        print(json.dumps(data))
+    elif options.output_format == "yaml":
+        print(yaml.dump(data).rstrip("\n"))
+    else:
+        print(
+            "Jobs (from %s to %s):" % (1 + options.start, options.start + options.limit)
+        )
+        for job in data:
+            print(
+                "* %s: %s (%s) - %s"
+                % (
+                    job["id"],
+                    job["submitter"],
+                    job["description"] if job["description"] else "",
+                    job["requested_device_type"],
+                )
+            )
+    return 0
+
+
 def handle_resubmit(proxy, options, config):
     job_id = proxy.scheduler.jobs.resubmit(options.job_id)
 
@@ -680,6 +734,7 @@ def handle(proxy, options, config):
         "definition": handle_definition,
         "list": handle_list,
         "logs": handle_logs,
+        "queue": handle_queue,
         "resubmit": handle_resubmit,
         "run": handle_run,
         "show": handle_show,
