@@ -18,6 +18,7 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import argparse
+import jinja2
 import yaml
 
 from . import jobs
@@ -45,6 +46,27 @@ def configure_parser(parser, _):
         "--raw", default=False, action="store_true", help="print raw logs"
     )
 
+    # "templates"
+    templates = sub.add_parser("templates", help="template helpers")
+    templates_sub = templates.add_subparsers(
+        dest="sub_sub_sub_command", help="Sub commands"
+    )
+    templates_sub.required = True
+
+    # "templates.render"
+    # TODO: add an option to be strict about undefined variables
+    templates_render = templates_sub.add_parser("render", help="render jinja2 template")
+    templates_render.add_argument(
+        "filename", type=argparse.FileType("r"), help="template"
+    )
+    templates_render.add_argument(
+        "--path",
+        type=str,
+        default=["/etc/lava-server/dispatcher-config/device-types"],
+        action="append",
+        help="templates lookup path",
+    )
+
 
 def help_string():
     return "utility functions"
@@ -59,6 +81,21 @@ def handle_logs(_, options):
         jobs.print_logs(logs, options.raw, options.filters)
 
 
+def handle_templates(_, options):
+    assert options.sub_sub_sub_command == "render"
+    env = jinja2.Environment(
+        autoescape=False, loader=jinja2.FileSystemLoader(options.path)
+    )
+    data = options.filename.read()
+    template = env.from_string(data)
+    try:
+        print(template.render())
+        return 0
+    except jinja2.TemplateNotFound:
+        print("Unable to find the templates")
+        return 1
+
+
 def handle(proxy, options, _):
-    handlers = {"logs": handle_logs}
+    handlers = {"logs": handle_logs, "templates": handle_templates}
     return handlers[options.sub_sub_command](proxy, options)
