@@ -27,25 +27,15 @@ def print_u(string):
         print(string.encode("ascii", errors="replace").decode("ascii"))
 
 
-(VERSION_2017_11,
- VERSION_2017_12,
- VERSION_2018_1,
- VERSION_2018_2,
- VERSION_LATEST) = range(5)
-
-VERSIONS = {
-    "2017.11": VERSION_2017_11,
-    "2017.12": VERSION_2017_12,
-    "2018.1": VERSION_2018_1,
-    "2018.2": VERSION_2018_2
-}
+VERSION_LATEST = (3000, 1)
 
 
 def parse_version(version):
-    pattern = re.compile(r"(?P<version>20\d{2}\.\d{1,2})")
+    pattern = re.compile(r"(?P<major>20\d{2})\.(?P<minor>\d{1,2})")
     if not isinstance(version, str):
         version = str(version)
     m = pattern.match(version)
     if m is None:
-        return None
-    return VERSIONS.get(m.groupdict()["version"], VERSION_LATEST)
+        return VERSION_LATEST
+    res = m.groupdict()
+    return (int(res["major"]), int(res["minor"]))
